Print API tweaks.

Change-Id: I4fcf93f17495740e8b8d0dc4e425a89862716b42
diff --git a/api/current.txt b/api/current.txt
index 7c7ebb2..667f564 100644
--- a/api/current.txt
+++ b/api/current.txt
@@ -18551,7 +18551,7 @@
     method public android.print.PrintAttributes getAttributes();
     method public int getId();
     method public java.lang.CharSequence getLabel();
-    method public android.print.PageRange[] getPageRanges();
+    method public android.print.PageRange[] getPages();
     method public android.print.PrinterId getPrinterId();
     method public int getState();
     method public java.lang.String getTag();
@@ -18572,10 +18572,6 @@
     method public android.print.PrintJob print(java.lang.String, android.print.PrintAdapter, android.print.PrintAttributes);
   }
 
-  public static abstract interface PrintManager.PrintJobStateListener {
-    method public abstract void onStateChanged(int);
-  }
-
   public final class PrinterId implements android.os.Parcelable {
     method public int describeContents();
     method public java.lang.String getLocalId();
diff --git a/core/java/android/print/PrintManager.java b/core/java/android/print/PrintManager.java
index df14a5c..32a0f5a 100644
--- a/core/java/android/print/PrintManager.java
+++ b/core/java/android/print/PrintManager.java
@@ -70,13 +70,6 @@
     private final Handler mHandler;
 
     /**
-     * Listener for the state of a print job.
-     */
-    public static interface PrintJobStateListener {
-        public void onStateChanged(int state);
-    }
-
-    /**
      * Creates a new instance.
      *
      * @param context The current context in which to operate.
diff --git a/core/java/android/print/PrintJobInfo.java b/core/java/android/print/PrintJobInfo.java
index 1a5d671..72d6057 100644
--- a/core/java/android/print/PrintJobInfo.java
+++ b/core/java/android/print/PrintJobInfo.java
@@ -261,22 +261,22 @@
     }
 
     /**
      * Gets the included page ranges.
      *
      * @return The included page ranges or <code>null</code> if not set.
      */
-    public PageRange[] getPageRanges() {
+    public PageRange[] getPages() {
         return mPageRanges;
     }
 
     /**
      * Sets the included page ranges.
      *
-     * @return The included page ranges.
+     * @return The included pages.
      *
      * @hide
      */
-    public void setPageRanges(PageRange[] pageRanges) {
+    public void setPages(PageRange[] pageRanges) {
         mPageRanges = pageRanges;
     }
 
@@ -261,22 +261,22 @@
 
     /**
-     * Gets the included page ranges.
+     * Gets the included pages.
      *
@@ -261,22 +261,22 @@
      *
-     * @return The included page ranges or <code>null</code> if not set.
+     * @return The included pages or <code>null</code> if not set.
      */
@@ -261,22 +261,22 @@
 
     /**
-     * Sets the included page ranges.
+     * Sets the included pages.
      *